## 申万行业日线行情

接口：sw_daily

描述：获取申万行业日线行情（默认是申万2021版行情）

限量：单次最大4000行数据，可通过指数代码和日期参数循环提取，5000积分可调取

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 行业代码 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 指数代码 |
| trade_date | str | Y | 交易日期 |
| name | str | Y | 指数名称 |
| open | float | Y | 开盘点位 |
| low | float | Y | 最低点位 |
| high | float | Y | 最高点位 |
| close | float | Y | 收盘点位 |
| change | float | Y | 涨跌点位 |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量（万股） |
| amount | float | Y | 成交额（万元） |
| pe | float | Y | 市盈率 |
| pb | float | Y | 市净率 |
| float_mv | float | Y | 流通市值（万元） |
| total_mv | float | Y | 总市值（万元） |

接口示例

```python
pro = ts.pro_api('your token')

#获取20230705当日所有申万行业指数的ts_code,name,open,close,vol,pe,pb数据
df = pro.sw_daily(trade_date='20230705', fields='ts_code,name,open,close,vol,pe,pb')
```

数据示例

```python
ts_code      name      open     close         vol      pe    pb
0    801001.SI      申万50   2972.86   2946.53   275984.00   13.99  1.91
```